@@ -8,23 +8,28 @@ if __name__ == "__main__":
     client = db.Historical(key=key)
 
     for schema in Schema:
-        if schema in (Schema.DEFINITION, Schema.STATISTICS, Schema.STATUS):
+        if schema in (
+            Schema.STATISTICS,
+            Schema.STATUS,
+            Schema.GATEWAY_ERROR,
+            Schema.SYMBOL_MAPPING,
+        ):
             continue
 
         print(schema.value)
 
-        path = f"test_data.{schema.value}.dbz"
+        path = f"test_data.{schema.value}.dbn.zst"
 
         # Execute request through client
-        data: Bento = client.timeseries.stream(
+        data: Bento = client.timeseries.get_range(
             dataset="GLBX.MDP3",
             symbols=["ESH1"],
             schema=schema,
             start="2020-12-28T13:00",
-            end="2020-12-29",
+            end="2020-12-29T13:00",
             limit=2,  # <-- limiting response to 2 records only (for test cases)
             path=path,
-        )  # -> FileBento
+        )  # -> Bento
 
         written = open(path, mode="rb").read()
         print(written)
